@@ -1,11 +1,9 @@
 package Email::Sender::Failure;
-our $VERSION = '0.093380';
+our $VERSION = '0.100110';
 use Moose;
+extends 'Throwable::Error';
 # ABSTRACT: a report of failure from an email sending transport
 
-with 'Email::Sender::Role::HasMessage';
-use overload '""' => sub { $_[0]->message }, fallback => 1;
-
 
 has code => (
   is => 'ro',
@@ -22,33 +20,14 @@ has _recipients => (
 sub recipients { shift->_recipients }
 
 
-sub throw {
-  my $inv = shift;
-  die $inv if ref $inv;
-  die $inv->new(@_);
-}
-
 sub BUILD {
   my ($self) = @_;
   confess("message must contain non-space characters")
     unless $self->message =~ /\S/;
 }
 
-sub BUILDARGS {
-  my ($self, @args) = @_;
 
-  return {} unless @args;
-  return {} if @args == 1 and ! defined $args[0];
-
-  if (@args == 1 and (!ref $args[0]) and defined $args[0] and length $args[0]) {
-    return { message => $args[0] };
-  }
-
-  return $self->SUPER::BUILDARGS(@args);
-}
-
-
-__PACKAGE__->meta->make_immutable;
+__PACKAGE__->meta->make_immutable(inline_constructor => 0);
 no Moose;
 1;
 
@@ -61,7 +40,7 @@ Email::Sender::Failure - a report of failure from an email sending transport
 
 =head1 VERSION
 
-version 0.093380
+version 0.100110
 
 =head1 ATTRIBUTES
 
@@ -110,7 +89,7 @@ be used as the C<message> of the new failure.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2009 by Ricardo Signes.
+This software is copyright (c) 2010 by Ricardo Signes.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
