@@ -1,5 +1,5 @@
 package Email::Sender::Failure::Multi;
-our $VERSION = '0.093380';
+our $VERSION = '0.100110';
 use Moose;
 extends 'Email::Sender::Failure';
 # ABSTRACT: an aggregate of multiple failures
@@ -33,7 +33,7 @@ sub isa {
   return $self->SUPER::isa($class);
 }
 
-__PACKAGE__->meta->make_immutable;
+__PACKAGE__->meta->make_immutable(inline_constructor => 0);
 no Moose;
 1;
 
@@ -46,7 +46,7 @@ Email::Sender::Failure::Multi - an aggregate of multiple failures
 
 =head1 VERSION
 
-version 0.093380
+version 0.100110
 
 =head1 DESCRIPTION
 
@@ -73,7 +73,7 @@ its contained failures are failures of that type.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2009 by Ricardo Signes.
+This software is copyright (c) 2010 by Ricardo Signes.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
